/*
-------------------------------------------------------------

                 Probabilistic Decision Diagrams

                           Interface
-------------------------------------------------------------
-------------------------------------------------------------
        Module              :           %M%
        Date                :           %G%
        Version             :           %I%
        Author              :           Dorel Marius Bozga
-------------------------------------------------------------
*/

#ifndef PDD_H
#define PDD_H

#if defined(__STDC__) || defined(__cplusplus)
#define ARGS(args) args
#else
#define ARGS(args) ()
#endif

#ifdef __cplusplus
#define EXTERN extern "C" 
#else
#define EXTERN extern 
#endif




/*
-------------------------------------------------------------
        Types
-------------------------------------------------------------
*/

typedef struct pdd_n {
  float proba;                              /* probability */
  int index;                             /* variable index */
  struct pdd_n* left;                        /* left child */
  struct pdd_n* right;                      /* right child */
  int flags;                                      /* flags */
  struct pdd_n* next;                     /* next in table */
} pdd;

typedef struct{
  int size;                             /* hash table size */
  pdd** entries;                            /* the entries */
} pdd_manager;




/*
-------------------------------------------------------------
        Functions
-------------------------------------------------------------
*/

EXTERN void pdd_create_manager ARGS((pdd_manager**));
EXTERN void pdd_delete_manager ARGS((pdd_manager**));

EXTERN pdd* pdd_mknode ARGS((pdd_manager*, float, int, pdd*, pdd*));

EXTERN pdd* pdd_create ARGS((pdd_manager*, float*, int));

EXTERN void pdd_print ARGS((pdd*, FILE*));
EXTERN void pdd_print_tree ARGS((pdd*, FILE*));

EXTERN int pdd_size ARGS((pdd*));

#endif
